@@ -2,7 +2,7 @@ from .circuit_braker import CircuitBreakerOpen, circuit_breaker  # noqa
 from .defaults import CacheDetect, context_cache_detect  # noqa
 from .early import early  # noqa
 from .fail import fail  # noqa
-from .invalidate import invalidate  # noqa
+from .invalidate import invalidate, invalidate_func  # noqa
 from .locked import locked  # noqa
 from .rate import PerfDegradationException, RateLimitException, hit, perf, rate_limit  # noqa
 from .simple import cache  # noqa
