@@ -15,10 +15,6 @@ def at(hour=23, minute=59, second=59, minimum: timedelta = timedelta(minutes=1),
     return _ttl
 
 
-def _not_decorator(func):
-    return func
-
-
 async def _is_disable_middleware(call, *args, backend=None, cmd=None, **kwargs):
     if backend.is_disable(cmd, "cmds"):
         return None
@@ -33,10 +29,15 @@ async def _auto_init(call, *args, backend=None, cmd=None, **kwargs):
 
 def add_prefix(prefix: str):
     async def _middleware(call, *args, backend=None, cmd=None, **kwargs):
+        if cmd.lower() == "get_many":
+            return await call(*[prefix + key for key in args])
         call_values = get_call_values(call, args, kwargs, func_args=None)
-        key = call_values.get("key")
+        as_key = "key"
+        if cmd == "delete_match":
+            as_key = "pattern"
+        key = call_values.get(as_key)
         if key:
-            call_values["key"] = prefix + key
+            call_values[as_key] = prefix + key
             return await call(**call_values)
         return await call(*args, **kwargs)
 
