@@ -1,16 +1,23 @@
 import inspect
+from datetime import timedelta
 from itertools import chain
-from typing import Any, Callable, Dict, Optional, Tuple
+from string import Formatter
+from typing import Any, Callable, Dict, Optional, Tuple, Union
 
-from .typing import FuncArgsType
+from .typing import TTL, FuncArgsType
+
+
+def ttl_to_seconds(ttl: Union[float, None, TTL]) -> Union[int, None, float]:
+    timeout = ttl() if callable(ttl) else ttl
+    return timeout.total_seconds() if isinstance(timeout, timedelta) else timeout
 
 
 def get_cache_key(
     func: Callable,
+    template: str = None,
     args: Tuple[Any] = (),
     kwargs: Optional[Dict] = None,
     func_args: FuncArgsType = None,
-    key: Optional[str] = None,
 ) -> str:
     """
     Get cache key name for function (:param func) called with args and kwargs
@@ -20,15 +27,13 @@ def get_cache_key(
     :param args: call positional arguments
     :param kwargs: call keyword arguments
     :param func_args: arguments that will be used in key
-    :param key: template for key, may contain alias to args or kwargs passed to a call
     :return: cache key for call
     """
     kwargs = kwargs or {}
     key_values = get_call_values(func, args, kwargs, func_args)
-    if key is None:
-        key_values = {k: str(v) if v is not None else "" for k, v in key_values.items()}
-        return ":".join([func.__module__, func.__name__, *chain(*key_values.items())]).lower()
-    return key.format(**key_values).lower()
+    key_values = {k: str(v) if v is not None else "" for k, v in key_values.items()}
+    _key_template = template or get_cache_key_template(func, func_args)
+    return _key_template.format(**key_values).lower()
 
 
 def get_func_params(func):
@@ -68,7 +73,7 @@ def get_call_values(func: Callable, args, kwargs, func_args: FuncArgsType) -> Di
     :param kwargs: call keyword arguments
     :param func_args: arguments that will be included in results (transformation function for values if passed as dict)
     """
-    key_values = {}
+    key_values = {key: "" for key in func_args or []}
     for _key, _value in _get_call_values(func, args, kwargs).items():
         if func_args is None or _key in func_args:
             key_values[_key] = _value
@@ -92,3 +97,26 @@ def _get_call_values(func, args, kwargs):
         else:
             result[_name] = _value
     return result
+
+
+class _Star(Formatter):
+    def get_value(self, key, args, kwds):
+        try:
+            return kwds[key]
+        except KeyError:
+            return "*"
+
+
+def template_to_pattern(template, _formatter=_Star(), **values):
+    return _formatter.format(template, **values).lower()
+
+
+_REGIRSTER = {}
+
+
+def register_template(func, template):
+    _REGIRSTER.setdefault((func.__module__, func.__name__), set()).add(template)
+
+
+def get_templates_for(func):
+    return _REGIRSTER.get((func.__module__, func.__name__), set())
