@@ -98,8 +98,8 @@ class Cache(ProxyBackend):
             key=key, value=value, expire=ttl_to_seconds(expire), exist=exist
         )
 
-    def get(self, key: str) -> Any:
-        return self._with_middlewares("get", self._target.get)(key=key)
+    def get(self, key: str, default: Optional[Any] = None) -> Any:
+        return self._with_middlewares("get", self._target.get)(key=key, default=default)
 
     def get_many(self, *keys: str):
         return self._with_middlewares("get_many", self._target.get_many)(*keys)
@@ -198,6 +198,8 @@ class Cache(ProxyBackend):
             "cache", cache_utils.invalidate(self, target=target, args_map=args_map, defaults=defaults)
         )
 
+    invalidate_func = cache_utils.invalidate_func
+
     def fail(
         self,
         ttl: TTL,
