@@ -58,7 +58,7 @@ async def test_expire(cache):
 @pytest.mark.parametrize(
     ("method", "args", "defaults"),
     (
-        ("get", ("key",), None),
+        ("get", ("key",), {"default": None}),
         ("set", ("key", "value"), {"exist": None, "expire": None}),
         ("incr", ("key",), None),
         ("delete", ("key",), None),
@@ -138,6 +138,7 @@ async def test_safe_redis():
     assert await redis.unlock("test", "test") is None
     assert await redis.is_locked("test") is None
 
+    assert await redis.get("test", default="no") == "no"
     assert await redis.get("test") is None
     assert await redis.get_many("test", "test2") == (None, None)
 
